@@ -2,7 +2,11 @@ from rrshare.rqSU.save_daily_counts_to_pikle import save_daily_counts_pickle
 
 def record_daily_counts_pickle():
     save_daily_counts_pickle()
+    
+if __name__ == "__main__":
+    record_daily_counts_pickle()
+    
 
 
-
-
+    
+    
\ No newline at end of file
